CREATE TABLE FOROS
(
	ACTIVO					VARCHAR(5)		NOT NULL,
	DESCRIPCION				VARCHAR(255)		NOT NULL,
	ID_FORO					SMALLINT		NOT NULL,
	NOMBRE					VARCHAR(100)		NOT NULL,
	ORDEN					TINYINT			NOT NULL,
	REQUIERE_PASS				VARCHAR(5)		NOT NULL,
	PASS					VARCHAR(50)		NULL,
	CONSTRAINT PK_FOROS PRIMARY KEY (ID_FORO)
)
GO

/* Tabla SubForos */
CREATE TABLE SUBFOROS
(
	ACTIVO					VARCHAR(5)		NOT NULL,
	DESCRIPCION				VARCHAR(255)	NOT NULL,
	ID_FORO					SMALLINT		NOT NULL,
	ID_SUBFORO				SMALLINT		NOT NULL,
	NOMBRE					VARCHAR(100)	NOT NULL,
	ORDEN					TINYINT			NOT NULL,
	PASS					VARCHAR(50)		NULL,
	REQUIERE_PASS			VARCHAR(5)		NOT NULL,
	SOLO_LECTURA			VARCHAR(5)		NOT NULL
)
GO

/* Tabla Tpicos */
CREATE TABLE TOPICOS
(
	ADJUNTO					VARCHAR(255)	NULL,
	ANUNCIO					VARCHAR(5)		NOT NULL,
	CERRADO					VARCHAR(5)		NOT NULL,
	CUERPO					TEXT			NOT NULL,
	FECHA_CREACION			VARCHAR(19)		NOT NULL,
	FECHA_ULT_RESP			VARCHAR(19)		NOT NULL,
	ID_AUTOR				INT				NOT NULL,
	ID_FORO					SMALLINT		NOT NULL,
	ID_SUBFORO				SMALLINT		NOT NULL,
	ID_TOPICO				INT				NOT NULL,
	NOMBRE					VARCHAR(125)	NOT NULL,
	VISITAS					INT				NOT NULL
)
GO

/* Tabla Respuestas */
CREATE TABLE RESPUESTAS
(
	ADJUNTO					VARCHAR(255)		NULL,
	CUERPO					TEXT			NOT NULL,
	FECHA_CREACION			VARCHAR(19)		NOT NULL,
	ID_AUTOR				INT				NOT NULL,
	ID_FORO					SMALLINT		NOT NULL,
	ID_RESPUESTA			INT				NOT NULL,
	ID_SUBFORO				SMALLINT		NOT NULL,
	ID_TOPICO				INT				NOT NULL,
	NOMBRE					VARCHAR(125)	NOT NULL
)
GO

/* Tabla Usuarios */
CREATE TABLE USUARIOS
(
	ACTIVO					VARCHAR(5)		NOT NULL,
	ACTUAL_VISITA				VARCHAR(19)		NOT NULL,
	AVATAR					VARCHAR(255)		NULL,
	EMAIL					VARCHAR(50)		NOT NULL,
	FECHA_REGISTRO				VARCHAR(19)		NOT NULL,
	FIRMA					TEXT			NULL,
	HASH_PASS				VARCHAR(35)		NOT NULL,
	HOST					VARCHAR(15)		NULL,
	ID_FORO					SMALLINT		NOT NULL,
	ID_USUARIO				INT			NOT NULL,
	IP					VARCHAR(15)		NULL,
	MENSAJES_NUEVOS				VARCHAR(5)		NOT NULL,
	NOMBRE					VARCHAR(40)		NOT NULL,
	NOMBRE_COMPLETO				VARCHAR(75)		NOT NULL,
	NUM_POSTS				INT			NOT NULL,
	ORGANIZACION				VARCHAR(75)		NULL,
	PAIS					VARCHAR(75)		NULL,
	PASS					VARCHAR(30)		NOT NULL,
	TIPO_USUARIO				SMALLINT		NOT NULL,
	ULTIMA_VISITA				VARCHAR(19)		NOT NULL,
	WEB					VARCHAR(255)		NULL,
	CONSTRAINT PK_USUARIOS PRIMARY KEY (ID_USUARIO)
)
GO

/* Tabla Opciones */
CREATE TABLE OPCIONES
(
	MOSTRAR_PUBLICIDAD			VARCHAR(5)		NOT NULL,
	NOMBRE					VARCHAR(100)		NOT NULL,
	NUM_USUARIOS				INT			NOT NULL,
	PERMITIR_ATTACHMENTS			VARCHAR(5)		NOT NULL,
	PERMITIR_AVATARES			VARCHAR(5)		NOT NULL,
	PERMITIR_FIRMAS				VARCHAR(5)		NOT NULL,
	PERMITIR_INVITADO			VARCHAR(5)		NOT NULL,
	URL_ORIGEN				VARCHAR(255)		NOT NULL
)
GO

/* Tabla Mensajes_Privados */
CREATE TABLE MENSAJES_PRIVADOS
(
	ALTA_PRIORIDAD				VARCHAR(5)		NOT NULL,
	ASUNTO					VARCHAR(100)		NOT NULL,
	CUERPO					TEXT			NOT NULL,
	FECHA_ENVIO				VARCHAR(19)		NOT NULL,
	ID_DESTINATARIO				INT			NOT NULL,
	ID_MENSAJE				INT			NOT NULL,
	ID_REMITENTE				INT			NOT NULL,
	LEIDO					VARCHAR(5)		NOT NULL
)
GO

/* CREACIN DE VALORES INICIALES / DE PARTIDA */

/* Foro de los Administradores generales */
INSERT INTO FOROS (ACTIVO,DESCRIPCION,ID_FORO,NOMBRE,ORDEN,REQUIERE_PASS,PASS)
	VALUES ('TRUE','Foro de Administradores',(-1),'Administradores Generales',0,'FALSE',NULL)
GO

/* Foro general de LWdP */
INSERT INTO FOROS (ACTIVO,DESCRIPCION,ID_FORO,NOMBRE,ORDEN,REQUIERE_PASS,PASS)
	VALUES ('TRUE','Foro general de La Web de Programacin',0,'La Web de Programacin',1,'FALSE',NULL)
GO

/* Opciones */
INSERT INTO OPCIONES (MOSTRAR_PUBLICIDAD,NOMBRE,NUM_USUARIOS,PERMITIR_ATTACHMENTS,PERMITIR_AVATARES,
														PERMITIR_FIRMAS,PERMITIR_INVITADO,URL_ORIGEN)
	VALUES ('FALSE','Foros de La Web de Programacin',1,'FALSE','TRUE','TRUE','TRUE',
												'http://www.lawebdeprogramacion.com')
GO

/* Usuario Baneado */
INSERT INTO USUARIOS (ACTIVO,ACTUAL_VISITA,AVATAR,EMAIL,FECHA_REGISTRO,FIRMA,HASH_PASS,HOST,ID_FORO,
	ID_USUARIO,IP,MENSAJES_NUEVOS,NOMBRE,NOMBRE_COMPLETO,NUM_POSTS,ORGANIZACION,PAIS,PASS,TIPO_USUARIO,
																					ULTIMA_VISITA,WEB)
	VALUES ('TRUE','01/01/2003 01:00:00',NULL,'no@email.es','01/01/2003 01:00:00',NULL,
			'8c1bc9d2010e2f1313e2fc96b7286e22',NULL,0,(-1),NULL,'FALSE','baneado',
				'Usuario Baneado',0,NULL,NULL,'baneado',(-1),'01/01/2003 01:00:00',NULL)
GO

/* Administrador General */
INSERT INTO USUARIOS (ACTIVO,ACTUAL_VISITA,AVATAR,EMAIL,FECHA_REGISTRO,FIRMA,HASH_PASS,HOST,ID_FORO,
	ID_USUARIO,IP,MENSAJES_NUEVOS,NOMBRE,NOMBRE_COMPLETO,NUM_POSTS,ORGANIZACION,PAIS,PASS,TIPO_USUARIO,
																					ULTIMA_VISITA,WEB)
	VALUES ('TRUE','01/01/2003 01:00:00',NULL,'Webmaster@lawebdeprogramacion.com','01/01/2003 01:00:00',
			NULL,'e5457eb7dd71df2b59deba91429146e6',NULL,(-1),1,NULL,'FALSE','admin','KaRt0nEs',0,
												NULL,NULL,'adminforolwdp',3,'01/01/2003 01:00:00',NULL)
GO
			


